@testable import SomeModule
import XCTest

final class BoolExtensionTests: SwiftLintTestCase {
    func testExample() {
        // some code
    }
}
